@@ -1,4 +1,4 @@
-"""TurtLSystems examples (https://pypi.org/project/turtlsystems)."""
+"""TurtLSystems examples (https://pypi.org/project/TurtLSystems)."""
 
 from TurtLSystems import draw
 draw('+A', 'A B-A-B B A+B+A,', 5, 60, 7, 2, (200, 220, 255), None, (36, 8, 107),
